BoxedMapped

Trait BoxedMapped 

pub trait BoxedMapped { }
Marker types for guards that are mapped by first being boxed (because they make no guarantees that their target reference can be detached from their location in memory.) Technically this could be anything, but the operation only really makes sense for guards, in order to return the mapping from a function.

Implementations on Foreign Types

Source

impl<'a, T> BoxedMapped for Ref<'a, T>

Source

impl<'a, T> BoxedMapped for MutexGuard<'a, T>

Source

impl<'a, T> BoxedMapped for RwLockReadGuard<'a, T>

Source

impl<'a, T> BoxedMapped for RwLockWriteGuard<'a, T>

Implementors

Source

impl<G, R> BoxedMapped for MappedGuard<G, R>